@@ -19,7 +19,7 @@ value *eval_assign(arena_state *s, expr *ex)
   
   val = eval_expr(s, ex->inner);
 
-  if (!s->except_flag) {
+  if (!s->except_flag && !s->exit_flag) {
     if (val->type != VALUE_TYPE_FN) {
       symtab_stack_add_variable(s, ex->name, val);
     } else {
@@ -45,6 +45,12 @@ value *array_set(arena_state *s, value *arr, int argc, expr **index,
   is_inner_struct = (argc > 1 && index[1]->type == EXPR_FIELD);
   
   pos = eval_expr(s, index[0]);
+
+  if (s->except_flag || s->exit_flag) {
+    value_free(pos);
+    return value_make_void();
+  }
+  
   if (is_struct) {
     realidx = pos->value_u.string_val.value;
   } else {
@@ -101,7 +107,7 @@ void eval_assign_array_direct(arena_state *s, const char *name,
 {
   symtab_entry *entry;
   value *arr = NULL;
-  int is_struct, is_old = 0;
+  int is_struct;
   
   sanity(name && index && *index && val);
   
@@ -117,15 +123,13 @@ void eval_assign_array_direct(arena_state *s, const char *name,
   } else {
     if (is_struct) {
       if (entry->entry_u.var->type == VALUE_TYPE_STRUCT) {
-        arr = entry->entry_u.var;
-        is_old = 1;
+        arr = value_copy(entry->entry_u.var);
       } else {
         arr = value_make_struct();
       }
     } else {
       if (entry->entry_u.var->type == VALUE_TYPE_ARRAY) {
-        arr = entry->entry_u.var;
-        is_old = 1;
+        arr = value_copy(entry->entry_u.var);
       } else {
         arr = value_make_array();
       }
@@ -133,10 +137,10 @@ void eval_assign_array_direct(arena_state *s, const char *name,
   }
 
   arr = array_set(s, arr, argc, index, val);
-  symtab_stack_add_variable(s, name, arr);
-  if (!is_old) {
-    value_free(arr);
+  if (!s->except_flag && !s->exit_flag) {
+    symtab_stack_add_variable(s, name, arr);
   }
+  value_free(arr);
 }
 
 /*
@@ -149,7 +153,7 @@ value *eval_assign_array(arena_state *s, expr *ex)
   sanity(ex && ex->name && ex->argc > 0 && ex->argv[0]);
   
   val = eval_expr(s, ex->inner);
-  if (!s->except_flag) {
+  if (!s->except_flag && !s->exit_flag) {
     eval_assign_array_direct(s, ex->name, ex->argc, ex->argv, val);
   }
   return val;
