@@ -129,10 +129,10 @@ value *eval_infix(arena_state *s, expr *ex)
       res = eval_math_mul(one, two);
       break;
     case OPTYPE_DIV:
-      res = eval_math_div(one, two);
+      res = eval_math_div(s, one, two);
       break;
     case OPTYPE_MOD:
-      res = eval_math_mod(one, two);
+      res = eval_math_mod(s, one, two);
       break;
     case OPTYPE_POW:
       res = eval_math_pow(one, two);
