@@ -65,11 +65,13 @@ static value *preincrement(arena_state *s, expr *ex)
   promote_prefix(s, &val, 0);
 
   ++val->value_u.int_val;
-  
-  if (ex->type == EXPR_REF) {
-    symtab_stack_add_variable(s, ex->name, val);
-  } else if (ex->type == EXPR_REF_ARRAY) {
-    eval_assign_array_direct(s, ex->name, ex->argc, ex->argv, val);
+
+  if (!s->except_flag && !s->exit_flag) {  
+    if (ex->type == EXPR_REF) {
+      symtab_stack_add_variable(s, ex->name, val);
+    } else if (ex->type == EXPR_REF_ARRAY) {
+      eval_assign_array_direct(s, ex->name, ex->argc, ex->argv, val);
+    }
   }
 
   return val;
@@ -86,11 +88,13 @@ static value *predecrement(arena_state *s, expr *ex)
   promote_prefix(s, &val, 0);
 
   --val->value_u.int_val;
-  
-  if (ex->type == EXPR_REF) {
-    symtab_stack_add_variable(s, ex->name, val);
-  } else if (ex->type == EXPR_REF_ARRAY) {
-    eval_assign_array_direct(s, ex->name, ex->argc, ex->argv, val);
+
+  if (!s->except_flag && !s->exit_flag) {  
+    if (ex->type == EXPR_REF) {
+      symtab_stack_add_variable(s, ex->name, val);
+    } else if (ex->type == EXPR_REF_ARRAY) {
+      eval_assign_array_direct(s, ex->name, ex->argc, ex->argv, val);
+    }
   }
 
   return val;
