@@ -34,7 +34,14 @@ static void errmsg(arena_state *s, int abort, const char *msg, va_list ap)
   vfprintf(stderr, msg, ap);
   fprintf(stderr, "\n");
 
-  if (abort) exit(1);
+  if (abort) {
+    if (s) {
+      s->exit_flag  = 1;
+      s->exit_value = -1;
+    } else {
+      exit(1);
+    }
+  }
 }
 
 /*
