@@ -9,16 +9,6 @@
 
 #include "runtime.h"
 
-/*
- * Register resource type
- *
- * This function allocates a new resource type id and returns it.
- */
-int reserve_resource_type(arena_state *s)
-{
-  return ++s->resource_max;
-}
-
 /*
  * Make void value
  *
@@ -187,7 +177,7 @@ value *value_make_fn(void *sig)
 /*
  * Make resource value
  */
-value *value_make_resource(int type, void *data, void (*release)(void *))
+value *value_make_resource(void *data, void (*release)(void *))
 {
   value *copy;
   
@@ -195,7 +185,6 @@ value *value_make_resource(int type, void *data, void (*release)(void *))
 
   copy->value_u.res_val = oom(malloc(sizeof(value_res)));
   copy->value_u.res_val->refcount = 1;
-  copy->value_u.res_val->type     = type;
   copy->value_u.res_val->data     = data;
   copy->value_u.res_val->release  = release;
   
