@@ -9,11 +9,6 @@
 
 #include "stdlib.h"
 
-/*
- * Flag whether random seed has been initialized
- */
-static int seed_init = 0;
-
 /*
  * Generate random int
  *
@@ -21,7 +16,7 @@ static int seed_init = 0;
  * specific range. The upper and lower bound are considered part
  * of the range.
  */
-value *rnd_random(unsigned int argc, value **argv)
+value *rnd_random(arena_state *s, unsigned int argc, value **argv)
 {
   int lower = argv[0]->value_u.int_val;
   int upper = argv[1]->value_u.int_val;
@@ -39,9 +34,9 @@ value *rnd_random(unsigned int argc, value **argv)
     upper = RAND_MAX;
   }
 
-  if (!seed_init) {
+  if (!s->seed_init) {
     srand(time(NULL));
-    seed_init = 1;
+    s->seed_init = 1;
   }
   
   scale = upper - lower + 1;
@@ -56,7 +51,7 @@ value *rnd_random(unsigned int argc, value **argv)
  * This function seeds the random generator with the given unsigned
  * int value.
  */
-value *rnd_srandom(unsigned int argc, value **argv)
+value *rnd_srandom(arena_state *s, unsigned int argc, value **argv)
 {
   srand(argv[0]->value_u.int_val);
   return value_make_void();
