@@ -229,6 +229,7 @@ static stdlib_func std[] = {
   /* functions on functions */
   { "is_builtin",	fn_is_builtin,		1,	"p",	'b'	},
   { "is_userdef",	fn_is_userdef,		1,	"p",	'b'	},
+  { "function_name",	fn_name,		1,	"p",	's'	},
   { "call",		fn_call,		1,	"p",	'?'	},
   { "call_array",	fn_call_array,		2,	"pa",	'?'	},
   { "call_method",	fn_call_method,		2,	"pc",	'?'	},
@@ -351,6 +352,7 @@ void stdlib_register(arena_state *s, int argc, char **argv)
   i = 0;
   while (std[i].name) {
     sig.args  = std[i].args;
+    sig.name  = std[i].name;
     sig.proto = std[i].proto;
     sig.call_u.builtin_vector = std[i].vector;
     sig.rettype = std[i].rettype;
