@@ -59,5 +59,5 @@ value *sys_system(arena_state *s, unsigned int argc, value **argv)
   if (res == -1) {
     return value_make_void();
   }
-  return value_make_int(res >> 8);
+  return value_make_int(res);
 }
