@@ -23,7 +23,7 @@ void cast_test(void)
   signature *sig;
   value *vvoid, *vbool, *vint, *vfloat, *vstring, *varray, *vstruct, *vfn;
 
-  sig = call_sig_builtin(0, "", dummy);
+  sig = call_sig_builtin("dummy", 0, "", dummy);
 
   test_banner("libruntime");
   
