@@ -33,7 +33,7 @@ void eval_test(void)
   stmt_list *slist;
 
   /* add myfunc to symbol table */
-  sig = call_sig_builtin(0, "", myfunc);
+  sig = call_sig_builtin("myfunc", 0, "", myfunc);
   symtab_stack_init(s);
   symtab_stack_enter(s);
   symtab_stack_add_function(s, "func", sig);
