@@ -53,13 +53,13 @@ void math_test(void)
   b = value_make_int(10);
   
   test_start("eval_math_div (int)");
-  res = eval_math_div(a, b);
+  res = eval_math_div(s, a, b);
   test_assert(res && res->type == VALUE_TYPE_INT &&
               res->value_u.int_val == 4);
   value_free(res);
 
   test_start("eval_math_mod (int)");
-  res = eval_math_mod(a, b);
+  res = eval_math_mod(s, a, b);
   test_assert(res && res->type == VALUE_TYPE_INT &&
               res->value_u.int_val == 2);
   value_free(res);
@@ -98,13 +98,13 @@ void math_test(void)
   value_free(res);
 
   test_start("eval_math_div (float)");
-  res = eval_math_div(a, b);
+  res = eval_math_div(s, a, b);
   test_assert(res && res->type == VALUE_TYPE_FLOAT &&
               res->value_u.float_val == 84.5);
   value_free(res);
 
   test_start("eval_math_mod (float)");
-  res = eval_math_mod(a, b);
+  res = eval_math_mod(s, a, b);
   test_assert(res && res->type == VALUE_TYPE_FLOAT &&
               res->value_u.float_val == 0.25);
   value_free(res);
