@@ -8,12 +8,14 @@
 
 int main(int argc, char **argv)
 {
+  arena_state *s = state_alloc();
+
   stmt_list *res;
 
   if (argc < 2) {
     return 1;
   }
-  res = parse_file(argv[1]); 
+  res = parse_file(s, argv[1]); 
   if (!res) {
     return 1;
   } else {
